# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["PromptUpdateParams"]


class PromptUpdateParams(TypedDict, total=False):
    body_id: Required[Annotated[str, PropertyInfo(alias="id")]]
    """The id of the prompt to update"""

    content: Required[str]
    """The content of the updated prompt"""

    parent: Required[str]
    """The parent of the updated prompt.

    Most times its the same as the id of the prompt to update.
    """

    branched: Optional[bool]
    """Whether the updated prompt is branched"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["PromptListParams"]


class PromptListParams(TypedDict, total=False):
    category: Required[str]
    """The category of the prompts to return"""

    from_: Required[Annotated[int, PropertyInfo(alias="from")]]
    """The pagination offset to start from (0-based)"""

    size: Required[int]
    """The number of prompts to return"""

    to: Required[int]
    """The pagination offset to end at (exclusive)"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

import os
from typing import Any, cast

import pytest

from tests.utils import assert_matches_type
from system_prompt_storage import SystemPromptStorage, AsyncSystemPromptStorage
from system_prompt_storage.types import (
    Prompt,
    PromptListResponse,
)

base_url = os.environ.get("TEST_API_BASE_URL", "http://127.0.0.1:4010")


class TestPrompts:
    parametrize = pytest.mark.parametrize("client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.create(
            content="content",
        )
        assert_matches_type(Prompt, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_create_with_all_params(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.create(
            content="content",
            branched=True,
            category="category",
            description="description",
            name="name",
            parent="parent",
            tags=["string"],
        )
        assert_matches_type(Prompt, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_create(self, client: SystemPromptStorage) -> None:
        response = client.prompts.with_raw_response.create(
            content="content",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = response.parse()
        assert_matches_type(Prompt, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_create(self, client: SystemPromptStorage) -> None:
        with client.prompts.with_streaming_response.create(
            content="content",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = response.parse()
            assert_matches_type(Prompt, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.retrieve(
            "id",
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve(self, client: SystemPromptStorage) -> None:
        response = client.prompts.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = response.parse()
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve(self, client: SystemPromptStorage) -> None:
        with client.prompts.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = response.parse()
            assert_matches_type(str, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve(self, client: SystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.prompts.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_update(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.update(
            path_id="id",
            body_id="id",
            content="content",
            parent="parent",
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_with_all_params(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.update(
            path_id="id",
            body_id="id",
            content="content",
            parent="parent",
            branched=True,
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update(self, client: SystemPromptStorage) -> None:
        response = client.prompts.with_raw_response.update(
            path_id="id",
            body_id="id",
            content="content",
            parent="parent",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = response.parse()
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update(self, client: SystemPromptStorage) -> None:
        with client.prompts.with_streaming_response.update(
            path_id="id",
            body_id="id",
            content="content",
            parent="parent",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = response.parse()
            assert_matches_type(str, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_update(self, client: SystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_id` but received ''"):
            client.prompts.with_raw_response.update(
                path_id="",
                body_id="id",
                content="content",
                parent="parent",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_list(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.list(
            category="category",
            from_=0,
            size=0,
            to=0,
        )
        assert_matches_type(PromptListResponse, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_list(self, client: SystemPromptStorage) -> None:
        response = client.prompts.with_raw_response.list(
            category="category",
            from_=0,
            size=0,
            to=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = response.parse()
        assert_matches_type(PromptListResponse, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_list(self, client: SystemPromptStorage) -> None:
        with client.prompts.with_streaming_response.list(
            category="category",
            from_=0,
            size=0,
            to=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = response.parse()
            assert_matches_type(PromptListResponse, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_method_delete(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.delete(
            "id",
        )
        assert prompt is None

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_delete(self, client: SystemPromptStorage) -> None:
        response = client.prompts.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = response.parse()
        assert prompt is None

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_delete(self, client: SystemPromptStorage) -> None:
        with client.prompts.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = response.parse()
            assert prompt is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_delete(self, client: SystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.prompts.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_retrieve_content(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.retrieve_content(
            id="id",
            latest=True,
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_retrieve_content(self, client: SystemPromptStorage) -> None:
        response = client.prompts.with_raw_response.retrieve_content(
            id="id",
            latest=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = response.parse()
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_retrieve_content(self, client: SystemPromptStorage) -> None:
        with client.prompts.with_streaming_response.retrieve_content(
            id="id",
            latest=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = response.parse()
            assert_matches_type(str, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_retrieve_content(self, client: SystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            client.prompts.with_raw_response.retrieve_content(
                id="",
                latest=True,
            )

    @pytest.mark.skip()
    @parametrize
    def test_method_update_metadata(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.update_metadata(
            path_id="id",
            body_id="id",
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_method_update_metadata_with_all_params(self, client: SystemPromptStorage) -> None:
        prompt = client.prompts.update_metadata(
            path_id="id",
            body_id="id",
            category="category",
            description="description",
            name="name",
            tags=["string"],
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_raw_response_update_metadata(self, client: SystemPromptStorage) -> None:
        response = client.prompts.with_raw_response.update_metadata(
            path_id="id",
            body_id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = response.parse()
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    def test_streaming_response_update_metadata(self, client: SystemPromptStorage) -> None:
        with client.prompts.with_streaming_response.update_metadata(
            path_id="id",
            body_id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = response.parse()
            assert_matches_type(str, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    def test_path_params_update_metadata(self, client: SystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_id` but received ''"):
            client.prompts.with_raw_response.update_metadata(
                path_id="",
                body_id="id",
            )


class TestAsyncPrompts:
    parametrize = pytest.mark.parametrize("async_client", [False, True], indirect=True, ids=["loose", "strict"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.create(
            content="content",
        )
        assert_matches_type(Prompt, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_create_with_all_params(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.create(
            content="content",
            branched=True,
            category="category",
            description="description",
            name="name",
            parent="parent",
            tags=["string"],
        )
        assert_matches_type(Prompt, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_create(self, async_client: AsyncSystemPromptStorage) -> None:
        response = await async_client.prompts.with_raw_response.create(
            content="content",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = await response.parse()
        assert_matches_type(Prompt, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_create(self, async_client: AsyncSystemPromptStorage) -> None:
        async with async_client.prompts.with_streaming_response.create(
            content="content",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = await response.parse()
            assert_matches_type(Prompt, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.retrieve(
            "id",
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve(self, async_client: AsyncSystemPromptStorage) -> None:
        response = await async_client.prompts.with_raw_response.retrieve(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = await response.parse()
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve(self, async_client: AsyncSystemPromptStorage) -> None:
        async with async_client.prompts.with_streaming_response.retrieve(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = await response.parse()
            assert_matches_type(str, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve(self, async_client: AsyncSystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.prompts.with_raw_response.retrieve(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.update(
            path_id="id",
            body_id="id",
            content="content",
            parent="parent",
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_with_all_params(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.update(
            path_id="id",
            body_id="id",
            content="content",
            parent="parent",
            branched=True,
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update(self, async_client: AsyncSystemPromptStorage) -> None:
        response = await async_client.prompts.with_raw_response.update(
            path_id="id",
            body_id="id",
            content="content",
            parent="parent",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = await response.parse()
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update(self, async_client: AsyncSystemPromptStorage) -> None:
        async with async_client.prompts.with_streaming_response.update(
            path_id="id",
            body_id="id",
            content="content",
            parent="parent",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = await response.parse()
            assert_matches_type(str, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_update(self, async_client: AsyncSystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_id` but received ''"):
            await async_client.prompts.with_raw_response.update(
                path_id="",
                body_id="id",
                content="content",
                parent="parent",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_list(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.list(
            category="category",
            from_=0,
            size=0,
            to=0,
        )
        assert_matches_type(PromptListResponse, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_list(self, async_client: AsyncSystemPromptStorage) -> None:
        response = await async_client.prompts.with_raw_response.list(
            category="category",
            from_=0,
            size=0,
            to=0,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = await response.parse()
        assert_matches_type(PromptListResponse, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_list(self, async_client: AsyncSystemPromptStorage) -> None:
        async with async_client.prompts.with_streaming_response.list(
            category="category",
            from_=0,
            size=0,
            to=0,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = await response.parse()
            assert_matches_type(PromptListResponse, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_method_delete(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.delete(
            "id",
        )
        assert prompt is None

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_delete(self, async_client: AsyncSystemPromptStorage) -> None:
        response = await async_client.prompts.with_raw_response.delete(
            "id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = await response.parse()
        assert prompt is None

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_delete(self, async_client: AsyncSystemPromptStorage) -> None:
        async with async_client.prompts.with_streaming_response.delete(
            "id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = await response.parse()
            assert prompt is None

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_delete(self, async_client: AsyncSystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.prompts.with_raw_response.delete(
                "",
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_retrieve_content(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.retrieve_content(
            id="id",
            latest=True,
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_retrieve_content(self, async_client: AsyncSystemPromptStorage) -> None:
        response = await async_client.prompts.with_raw_response.retrieve_content(
            id="id",
            latest=True,
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = await response.parse()
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_retrieve_content(self, async_client: AsyncSystemPromptStorage) -> None:
        async with async_client.prompts.with_streaming_response.retrieve_content(
            id="id",
            latest=True,
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = await response.parse()
            assert_matches_type(str, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_retrieve_content(self, async_client: AsyncSystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `id` but received ''"):
            await async_client.prompts.with_raw_response.retrieve_content(
                id="",
                latest=True,
            )

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_metadata(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.update_metadata(
            path_id="id",
            body_id="id",
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_method_update_metadata_with_all_params(self, async_client: AsyncSystemPromptStorage) -> None:
        prompt = await async_client.prompts.update_metadata(
            path_id="id",
            body_id="id",
            category="category",
            description="description",
            name="name",
            tags=["string"],
        )
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_raw_response_update_metadata(self, async_client: AsyncSystemPromptStorage) -> None:
        response = await async_client.prompts.with_raw_response.update_metadata(
            path_id="id",
            body_id="id",
        )

        assert response.is_closed is True
        assert response.http_request.headers.get("X-Stainless-Lang") == "python"
        prompt = await response.parse()
        assert_matches_type(str, prompt, path=["response"])

    @pytest.mark.skip()
    @parametrize
    async def test_streaming_response_update_metadata(self, async_client: AsyncSystemPromptStorage) -> None:
        async with async_client.prompts.with_streaming_response.update_metadata(
            path_id="id",
            body_id="id",
        ) as response:
            assert not response.is_closed
            assert response.http_request.headers.get("X-Stainless-Lang") == "python"

            prompt = await response.parse()
            assert_matches_type(str, prompt, path=["response"])

        assert cast(Any, response.is_closed) is True

    @pytest.mark.skip()
    @parametrize
    async def test_path_params_update_metadata(self, async_client: AsyncSystemPromptStorage) -> None:
        with pytest.raises(ValueError, match=r"Expected a non-empty value for `path_id` but received ''"):
            await async_client.prompts.with_raw_response.update_metadata(
                path_id="",
                body_id="id",
            )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List, Optional

from .._models import BaseModel

__all__ = ["Prompt", "Metadata"]


class Metadata(BaseModel):
    category: Optional[str] = None
    """Category of the prompt ie React, typescript, etc."""

    description: Optional[str] = None
    """Description of the prompt"""

    name: Optional[str] = None
    """Name of the prompt"""

    tags: Optional[List[str]] = None
    """Tags of the prompt ie [react, typescript, etc.]"""


class Prompt(BaseModel):
    id: str
    """The id of the prompt"""

    content: str
    """The content of the prompt"""

    created_at: int
    """The creation date of the prompt"""

    parent: str
    """The parent of the prompt"""

    version: int
    """The version of the prompt"""

    archived: Optional[bool] = None
    """Whether the prompt is archived"""

    branched: Optional[bool] = None
    """Whether the prompt is being branched"""

    metadata: Optional[Metadata] = None
    """The metadata of the prompt"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing_extensions import Required, TypedDict

__all__ = ["PromptRetrieveContentParams"]


class PromptRetrieveContentParams(TypedDict, total=False):
    latest: Required[bool]
    """Latest version of the prompt"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .prompt import Prompt

__all__ = ["PromptListResponse"]

PromptListResponse: TypeAlias = List[Prompt]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from .prompt import Prompt as Prompt
from .prompt_list_params import PromptListParams as PromptListParams
from .prompt_create_params import PromptCreateParams as PromptCreateParams
from .prompt_list_response import PromptListResponse as PromptListResponse
from .prompt_update_params import PromptUpdateParams as PromptUpdateParams
from .prompt_update_response import PromptUpdateResponse as PromptUpdateResponse
from .prompt_retrieve_response import PromptRetrieveResponse as PromptRetrieveResponse
from .prompt_update_metadata_params import PromptUpdateMetadataParams as PromptUpdateMetadataParams
from .prompt_retrieve_content_params import PromptRetrieveContentParams as PromptRetrieveContentParams
from .prompt_update_metadata_response import PromptUpdateMetadataResponse as PromptUpdateMetadataResponse
from .prompt_retrieve_content_response import PromptRetrieveContentResponse as PromptRetrieveContentResponse



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional

import httpx

from ..types import (
    prompt_list_params,
    prompt_create_params,
    prompt_update_params,
    prompt_update_metadata_params,
    prompt_retrieve_content_params,
)
from .._types import NOT_GIVEN, Body, Query, Headers, NoneType, NotGiven
from .._utils import maybe_transform, async_maybe_transform
from .._compat import cached_property
from .._resource import SyncAPIResource, AsyncAPIResource
from .._response import (
    to_raw_response_wrapper,
    to_streamed_response_wrapper,
    async_to_raw_response_wrapper,
    async_to_streamed_response_wrapper,
)
from .._base_client import make_request_options
from ..types.prompt import Prompt
from ..types.prompt_list_response import PromptListResponse

__all__ = ["PromptsResource", "AsyncPromptsResource"]


class PromptsResource(SyncAPIResource):
    @cached_property
    def with_raw_response(self) -> PromptsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cruzluna/sps-python#accessing-raw-response-data-eg-headers
        """
        return PromptsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> PromptsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cruzluna/sps-python#with_streaming_response
        """
        return PromptsResourceWithStreamingResponse(self)

    def create(
        self,
        *,
        content: str,
        branched: Optional[bool] | NotGiven = NOT_GIVEN,
        category: Optional[str] | NotGiven = NOT_GIVEN,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        name: Optional[str] | NotGiven = NOT_GIVEN,
        parent: Optional[str] | NotGiven = NOT_GIVEN,
        tags: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Prompt:
        """
        Create prompt

        Args:
          content: The content of the prompt

          branched: Whether the prompt is being branched

          category: The category of the prompt

          description: The description of the prompt

          name: The name of the prompt

          parent: The parent of the prompt. If its a new prompt with no lineage, this should be
              None.

          tags: The tags of the prompt

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._post(
            "/prompt",
            body=maybe_transform(
                {
                    "content": content,
                    "branched": branched,
                    "category": category,
                    "description": description,
                    "name": name,
                    "parent": parent,
                    "tags": tags,
                },
                prompt_create_params.PromptCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Prompt,
        )

    def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Get prompt

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            f"/prompt/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def update(
        self,
        path_id: str,
        *,
        body_id: str,
        content: str,
        parent: str,
        branched: Optional[bool] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Update prompt

        Args:
          body_id: The id of the prompt to update

          content: The content of the updated prompt

          parent: The parent of the updated prompt. Most times its the same as the id of the
              prompt to update.

          branched: Whether the updated prompt is branched

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._put(
            f"/prompt/{path_id}",
            body=maybe_transform(
                {
                    "body_id": body_id,
                    "content": content,
                    "parent": parent,
                    "branched": branched,
                },
                prompt_update_params.PromptUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    def list(
        self,
        *,
        category: str,
        from_: int,
        size: int,
        to: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PromptListResponse:
        """
        Get list of prompts with pagination

        Args:
          category: The category of the prompts to return

          from_: The pagination offset to start from (0-based)

          size: The number of prompts to return

          to: The pagination offset to end at (exclusive)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return self._get(
            "/prompts",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform(
                    {
                        "category": category,
                        "from_": from_,
                        "size": size,
                        "to": to,
                    },
                    prompt_list_params.PromptListParams,
                ),
            ),
            cast_to=PromptListResponse,
        )

    def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete prompt

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return self._delete(
            f"/prompt/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    def retrieve_content(
        self,
        id: str,
        *,
        latest: bool,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Get prompt content

        Args:
          latest: Latest version of the prompt

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._get(
            f"/prompt/{id}/content",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=maybe_transform({"latest": latest}, prompt_retrieve_content_params.PromptRetrieveContentParams),
            ),
            cast_to=str,
        )

    def update_metadata(
        self,
        path_id: str,
        *,
        body_id: str,
        category: Optional[str] | NotGiven = NOT_GIVEN,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        name: Optional[str] | NotGiven = NOT_GIVEN,
        tags: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Update prompt metadata

        Args:
          body_id: The id of the prompt

          category: The category of the prompt

          description: The description of the prompt

          name: The name of the prompt

          tags: The tags of the prompt

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return self._put(
            f"/prompt/{path_id}/metadata",
            body=maybe_transform(
                {
                    "body_id": body_id,
                    "category": category,
                    "description": description,
                    "name": name,
                    "tags": tags,
                },
                prompt_update_metadata_params.PromptUpdateMetadataParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class AsyncPromptsResource(AsyncAPIResource):
    @cached_property
    def with_raw_response(self) -> AsyncPromptsResourceWithRawResponse:
        """
        This property can be used as a prefix for any HTTP method call to return
        the raw response object instead of the parsed content.

        For more information, see https://www.github.com/cruzluna/sps-python#accessing-raw-response-data-eg-headers
        """
        return AsyncPromptsResourceWithRawResponse(self)

    @cached_property
    def with_streaming_response(self) -> AsyncPromptsResourceWithStreamingResponse:
        """
        An alternative to `.with_raw_response` that doesn't eagerly read the response body.

        For more information, see https://www.github.com/cruzluna/sps-python#with_streaming_response
        """
        return AsyncPromptsResourceWithStreamingResponse(self)

    async def create(
        self,
        *,
        content: str,
        branched: Optional[bool] | NotGiven = NOT_GIVEN,
        category: Optional[str] | NotGiven = NOT_GIVEN,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        name: Optional[str] | NotGiven = NOT_GIVEN,
        parent: Optional[str] | NotGiven = NOT_GIVEN,
        tags: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> Prompt:
        """
        Create prompt

        Args:
          content: The content of the prompt

          branched: Whether the prompt is being branched

          category: The category of the prompt

          description: The description of the prompt

          name: The name of the prompt

          parent: The parent of the prompt. If its a new prompt with no lineage, this should be
              None.

          tags: The tags of the prompt

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._post(
            "/prompt",
            body=await async_maybe_transform(
                {
                    "content": content,
                    "branched": branched,
                    "category": category,
                    "description": description,
                    "name": name,
                    "parent": parent,
                    "tags": tags,
                },
                prompt_create_params.PromptCreateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=Prompt,
        )

    async def retrieve(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Get prompt

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            f"/prompt/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def update(
        self,
        path_id: str,
        *,
        body_id: str,
        content: str,
        parent: str,
        branched: Optional[bool] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Update prompt

        Args:
          body_id: The id of the prompt to update

          content: The content of the updated prompt

          parent: The parent of the updated prompt. Most times its the same as the id of the
              prompt to update.

          branched: Whether the updated prompt is branched

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._put(
            f"/prompt/{path_id}",
            body=await async_maybe_transform(
                {
                    "body_id": body_id,
                    "content": content,
                    "parent": parent,
                    "branched": branched,
                },
                prompt_update_params.PromptUpdateParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )

    async def list(
        self,
        *,
        category: str,
        from_: int,
        size: int,
        to: int,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> PromptListResponse:
        """
        Get list of prompts with pagination

        Args:
          category: The category of the prompts to return

          from_: The pagination offset to start from (0-based)

          size: The number of prompts to return

          to: The pagination offset to end at (exclusive)

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        return await self._get(
            "/prompts",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {
                        "category": category,
                        "from_": from_,
                        "size": size,
                        "to": to,
                    },
                    prompt_list_params.PromptListParams,
                ),
            ),
            cast_to=PromptListResponse,
        )

    async def delete(
        self,
        id: str,
        *,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> None:
        """
        Delete prompt

        Args:
          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "*/*", **(extra_headers or {})}
        return await self._delete(
            f"/prompt/{id}",
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=NoneType,
        )

    async def retrieve_content(
        self,
        id: str,
        *,
        latest: bool,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Get prompt content

        Args:
          latest: Latest version of the prompt

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not id:
            raise ValueError(f"Expected a non-empty value for `id` but received {id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._get(
            f"/prompt/{id}/content",
            options=make_request_options(
                extra_headers=extra_headers,
                extra_query=extra_query,
                extra_body=extra_body,
                timeout=timeout,
                query=await async_maybe_transform(
                    {"latest": latest}, prompt_retrieve_content_params.PromptRetrieveContentParams
                ),
            ),
            cast_to=str,
        )

    async def update_metadata(
        self,
        path_id: str,
        *,
        body_id: str,
        category: Optional[str] | NotGiven = NOT_GIVEN,
        description: Optional[str] | NotGiven = NOT_GIVEN,
        name: Optional[str] | NotGiven = NOT_GIVEN,
        tags: Optional[List[str]] | NotGiven = NOT_GIVEN,
        # Use the following arguments if you need to pass additional parameters to the API that aren't available via kwargs.
        # The extra values given here take precedence over values defined on the client or passed to this method.
        extra_headers: Headers | None = None,
        extra_query: Query | None = None,
        extra_body: Body | None = None,
        timeout: float | httpx.Timeout | None | NotGiven = NOT_GIVEN,
    ) -> str:
        """
        Update prompt metadata

        Args:
          body_id: The id of the prompt

          category: The category of the prompt

          description: The description of the prompt

          name: The name of the prompt

          tags: The tags of the prompt

          extra_headers: Send extra headers

          extra_query: Add additional query parameters to the request

          extra_body: Add additional JSON properties to the request

          timeout: Override the client-level default timeout for this request, in seconds
        """
        if not path_id:
            raise ValueError(f"Expected a non-empty value for `path_id` but received {path_id!r}")
        extra_headers = {"Accept": "text/plain", **(extra_headers or {})}
        return await self._put(
            f"/prompt/{path_id}/metadata",
            body=await async_maybe_transform(
                {
                    "body_id": body_id,
                    "category": category,
                    "description": description,
                    "name": name,
                    "tags": tags,
                },
                prompt_update_metadata_params.PromptUpdateMetadataParams,
            ),
            options=make_request_options(
                extra_headers=extra_headers, extra_query=extra_query, extra_body=extra_body, timeout=timeout
            ),
            cast_to=str,
        )


class PromptsResourceWithRawResponse:
    def __init__(self, prompts: PromptsResource) -> None:
        self._prompts = prompts

        self.create = to_raw_response_wrapper(
            prompts.create,
        )
        self.retrieve = to_raw_response_wrapper(
            prompts.retrieve,
        )
        self.update = to_raw_response_wrapper(
            prompts.update,
        )
        self.list = to_raw_response_wrapper(
            prompts.list,
        )
        self.delete = to_raw_response_wrapper(
            prompts.delete,
        )
        self.retrieve_content = to_raw_response_wrapper(
            prompts.retrieve_content,
        )
        self.update_metadata = to_raw_response_wrapper(
            prompts.update_metadata,
        )


class AsyncPromptsResourceWithRawResponse:
    def __init__(self, prompts: AsyncPromptsResource) -> None:
        self._prompts = prompts

        self.create = async_to_raw_response_wrapper(
            prompts.create,
        )
        self.retrieve = async_to_raw_response_wrapper(
            prompts.retrieve,
        )
        self.update = async_to_raw_response_wrapper(
            prompts.update,
        )
        self.list = async_to_raw_response_wrapper(
            prompts.list,
        )
        self.delete = async_to_raw_response_wrapper(
            prompts.delete,
        )
        self.retrieve_content = async_to_raw_response_wrapper(
            prompts.retrieve_content,
        )
        self.update_metadata = async_to_raw_response_wrapper(
            prompts.update_metadata,
        )


class PromptsResourceWithStreamingResponse:
    def __init__(self, prompts: PromptsResource) -> None:
        self._prompts = prompts

        self.create = to_streamed_response_wrapper(
            prompts.create,
        )
        self.retrieve = to_streamed_response_wrapper(
            prompts.retrieve,
        )
        self.update = to_streamed_response_wrapper(
            prompts.update,
        )
        self.list = to_streamed_response_wrapper(
            prompts.list,
        )
        self.delete = to_streamed_response_wrapper(
            prompts.delete,
        )
        self.retrieve_content = to_streamed_response_wrapper(
            prompts.retrieve_content,
        )
        self.update_metadata = to_streamed_response_wrapper(
            prompts.update_metadata,
        )


class AsyncPromptsResourceWithStreamingResponse:
    def __init__(self, prompts: AsyncPromptsResource) -> None:
        self._prompts = prompts

        self.create = async_to_streamed_response_wrapper(
            prompts.create,
        )
        self.retrieve = async_to_streamed_response_wrapper(
            prompts.retrieve,
        )
        self.update = async_to_streamed_response_wrapper(
            prompts.update,
        )
        self.list = async_to_streamed_response_wrapper(
            prompts.list,
        )
        self.delete = async_to_streamed_response_wrapper(
            prompts.delete,
        )
        self.retrieve_content = async_to_streamed_response_wrapper(
            prompts.retrieve_content,
        )
        self.update_metadata = async_to_streamed_response_wrapper(
            prompts.update_metadata,
        )



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from .prompts import (
    PromptsResource,
    AsyncPromptsResource,
    PromptsResourceWithRawResponse,
    AsyncPromptsResourceWithRawResponse,
    PromptsResourceWithStreamingResponse,
    AsyncPromptsResourceWithStreamingResponse,
)

__all__ = [
    "PromptsResource",
    "AsyncPromptsResource",
    "PromptsResourceWithRawResponse",
    "AsyncPromptsResourceWithRawResponse",
    "PromptsResourceWithStreamingResponse",
    "AsyncPromptsResourceWithStreamingResponse",
]



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, TypedDict

__all__ = ["PromptCreateParams"]


class PromptCreateParams(TypedDict, total=False):
    content: Required[str]
    """The content of the prompt"""

    branched: Optional[bool]
    """Whether the prompt is being branched"""

    category: Optional[str]
    """The category of the prompt"""

    description: Optional[str]
    """The description of the prompt"""

    name: Optional[str]
    """The name of the prompt"""

    parent: Optional[str]
    """The parent of the prompt.

    If its a new prompt with no lineage, this should be None.
    """

    tags: Optional[List[str]]
    """The tags of the prompt"""



# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from __future__ import annotations

from typing import List, Optional
from typing_extensions import Required, Annotated, TypedDict

from .._utils import PropertyInfo

__all__ = ["PromptUpdateMetadataParams"]


class PromptUpdateMetadataParams(TypedDict, total=False):
    body_id: Required[Annotated[str, PropertyInfo(alias="id")]]
    """The id of the prompt"""

    category: Optional[str]
    """The category of the prompt"""

    description: Optional[str]
    """The description of the prompt"""

    name: Optional[str]
    """The name of the prompt"""

    tags: Optional[List[str]]
    """The tags of the prompt"""
